% plot vg via angle variance with error bar
% Write by Zhenyu on 2022/05/15
% Paper Figure 4 (setting the same as Program 'F4_speckle_AdjTilt_Gauss')
% Before figures save: this figure should select 24cm_18cm preset
%% load data----------------------------------------------------------
clf;
clear;
close all;

tilt_num = 10;           % number of calculated different tilt cases
tilt_max = 5*pi/180;     % maximum (or variance) tilt angle for wave front with x/y
lambda = 1550e-9;        % wavelength (unit: m)
data_address = 'D:\PhD research\Structured Slow Light\1-speckle propagation\numerical calculation\results\Results for paper\matdata\'; % data save address
num = 8;                 % data number (from 1 to num)
average_kr2_data = zeros(tilt_num,num);
vg_c_data = zeros(tilt_num,num);
for m = 1:1:num
    dataname = strcat(data_address,'Gaussian_',num2str(round(lambda*1e9)),' variance angle_',num2str(tilt_max/pi*180),' data',num2str(m),'.mat');
    load(dataname);
    average_kr2_data(:,m) = average_kr2;
    vg_c_data(:,m) = vg_c;
end

k0 = 2*pi/lambda;
average_kr2_data = average_kr2_data/(k0^2);     % kr^2/k0^2
average_kr2_mean = mean(average_kr2_data,2);
vg_c_data_mean = mean(vg_c_data,2);

average_kr2_err = std(average_kr2_data,1,2);
vg_c_err = std(vg_c_data,1,2);

tilt_axis_theo = linspace(0,max(tilt_axis)+min(tilt_axis),1000);
average_kr2_theo = 3*(sin(tilt_axis_theo)).^2;
vg_c_theo = sqrt(1-average_kr2_theo)-1;

tilt_axis = rad2deg(tilt_axis);
tilt_axis_theo = rad2deg(tilt_axis_theo);

set(gcf,'position',[300 200 800 600]);

subplot(2,1,1);     % kr^2/k0^2 via angle variance
set(gca,'position', [0.12 0.56 0.8 0.4]);
plot(tilt_axis_theo,average_kr2_theo,'b','linewidth',1.5);     % ideal line
hold on
plot(tilt_axis,average_kr2_mean,'m.','MarkerSize',15);
errorbar(tilt_axis,average_kr2_mean,average_kr2_err,'m.','linewidth',1.5);
% xlabel('$\sigma_\theta$ $(^{\circ})$','interpreter','latex','fontsize',18);
ylabel('$<k_r^2>/k_0^2$','interpreter','latex','fontsize',18,'Position',[-0.47,0.015]);
title('\bf(a)','fontsize',22,'Position',[0.25,0.023],'FontName','Times New Roman','color','k');
axis([0,max(tilt_axis)+min(tilt_axis),0,0.03]);
set(gca,'xticklabel',[],'ytick',0:0.01:0.03)
grid on; set(gca,'GridLineStyle','--','GridAlpha',0.2);
hold off

subplot(2,1,2);     % vg/c via angle variance
set(gca,'position', [0.12 0.12 0.8 0.4]);
plot(tilt_axis_theo,vg_c_theo,'b','linewidth',1.5);
hold on
plot(tilt_axis,vg_c_data_mean,'m.','MarkerSize',15);
errorbar(tilt_axis,vg_c_data_mean,vg_c_err,'m.','linewidth',1.5);
xlabel('$\sigma_\theta$ $(^{\circ})$','interpreter','latex','fontsize',18);
ylabel('$v_g/c-1$','interpreter','latex','fontsize',18);
title('\bf(b)','fontsize',22,'Position',[0.25,-0.0034],'FontName','Times New Roman','color','k');
axis([0,max(tilt_axis)+min(tilt_axis),-0.015,0]);
grid on; set(gca,'GridLineStyle','--','GridAlpha',0.2);
set(gca,'XTick',(0:0.5:5));
set(gca,'xticklabel',{'0',' ','1',' ','2',' ','3',' ','4',' ','5'});
set(gca,'yticklabel',{'-1.5%','-1.0%', '-0.5%', '0'});
set(gca,'FontName','Times New Roman');
hold off