% plot vg via Beam aperture and Numerical aperture with error bar
% Write by Zhenyu Wan on 2022/05/20
% Paper Figure 5 (setting same as Program 'F5_speckle_AdjAperture')
% Before figures save: this figure should select 24cm_18cm preset;
%% load data----------------------------------------------------------
clf;
clear;
close all;

num = 8;                 % data number (from 1 to num)
Ap_num = 10;             % number of calculated different tilt cases
Aperture_max = 2e-3;        % size of beam aperture (maximum)
NA_max = sin(20*pi/180);    % Numerical aperture of the detect system (maximum)
tilt_max = 5*pi/180;     % maximum (or variance) tilt angle for wave front with x/y
lambda = 1550e-9;        % wavelength (unit: m)
k0 = 2*pi/lambda;
waist0 = 2e-3;           % waist of Gaussian components (unit: m)
data_address = 'D:\PhD research\Structured Slow Light\1-speckle propagation\numerical calculation\results\Results for paper\matdata\'; % data save address

average_kr2_data_BA = zeros(Ap_num,num);
vg_c_data_BA = zeros(Ap_num,num);
average_kr2_data_NA = zeros(Ap_num,num);
vg_c_data_NA = zeros(Ap_num,num);
for m = 1:1:num
    dataname = strcat(data_address,'3-AdjAperture @',num2str(round(lambda*1e9)),' Angle_',num2str(tilt_max/pi*180),' w0_',num2str(waist0*1e3),' MaxBA_',num2str(Aperture_max*1e3),' MaxNA_',num2str(NA_max),' data',num2str(m),'.mat');
    load(dataname);
    average_kr2_data_BA(:,m) = average_kr2_BA;
    average_kr2_data_NA(:,m) = average_kr2_NA;
    vg_c_data_BA(:,m) = vg_c_BA;
    vg_c_data_NA(:,m) = vg_c_NA;
end

% average & error of beam aperture
average_kr2_BA_mean = mean(average_kr2_data_BA,2);
average_kr2_BA_err = std(average_kr2_data_BA,1,2);
vg_c_data_BA_mean = mean(vg_c_data_BA,2);
vg_c_BA_err = std(vg_c_data_BA,1,2);

% average & error of numerical aperture
average_kr2_NA_mean = mean(average_kr2_data_NA,2);
average_kr2_NA_err = std(average_kr2_data_NA,1,2);
vg_c_data_NA_mean = mean(vg_c_data_NA,2);
vg_c_NA_err = std(vg_c_data_NA,1,2);

% theoretical value of beam aperture
Aperture_size_theo = linspace(0,max(Aperture_size)+min(Aperture_size),200);
average_kr2_theo = 3*(sin(tilt_max))^2*ones(1,200);
vg_c_theo = sqrt(1-average_kr2_theo)-1;

% theoretical value of numerical aperture
syms kr2 NA_k
sigma = sin(tilt_max);
f1 = kr2^(3/2)*exp(-kr2/2/sigma^2);
f2 = kr2^(1/2)*exp(-kr2/2/sigma^2);
NA_size_theo = linspace(0,max(NA_size)+min(NA_size),200);
average_kr2_NA_theo = zeros(1,200);
for m = 1:1:200
    f_numeritor = int(f1,kr2,0,NA_size_theo(m)^2);
    f_denominator = int(f2,kr2,0,NA_size_theo(m)^2);
    average_kr2_NA_theo(m) = f_numeritor/f_denominator;
end
average_kr2_NA_theo(1) = 0;
vg_c_NA_theo = sqrt(1-average_kr2_NA_theo)-1;

%%
figure
set(gcf,'position',[300 200 800 600]);

subplot(2,1,1);     % vg/c via beam aperture
set(gca,'position', [0.12 0.60 0.7 0.38]);
plot(Aperture_size_theo,vg_c_theo,'b','linewidth',1.5);     % ideal line
hold on
plot(Aperture_size,vg_c_data_BA_mean,'m.','MarkerSize',15);
errorbar(Aperture_size,vg_c_data_BA_mean,vg_c_BA_err,'m.','linewidth',1.5);
xlabel('$Aperture /mm$','interpreter','latex','fontsize',18);
ylabel('$v_g/c-1$','interpreter','latex','fontsize',18);
axis([0,max(Aperture_size_theo)+min(Aperture_size_theo),-0.016,0]);
set(gca,'XTick',(0:0.2e-3:2e-3));
set(gca,'xticklabel',{'0',' ','0.4',' ','0.8',' ','1.2',' ','1.6',' ','2.0'});
set(gca,'YTick',(-0.016:0.004:0));
set(gca,'yticklabel',{'-1.6%','-1.2%', '-0.8%', '-0.4%', '0'});
grid on; set(gca,'GridLineStyle','--','GridAlpha',0.2);
set(gca,'FontName','Times New Roman');
hold off

subplot(2,1,2);     % vg/c via numerical aperture
set(gca,'position', [0.12 0.10 0.7 0.38]);
plot(NA_size_theo,vg_c_NA_theo,'b','linewidth',1.5);
hold on
plot(NA_size_theo,vg_c_theo,'b--','linewidth',1.5);     % ideal line
plot(NA_size,vg_c_data_NA_mean,'m.','MarkerSize',15);
errorbar(NA_size,vg_c_data_NA_mean,vg_c_NA_err,'m.','linewidth',1.5);
xlabel('$NA$','interpreter','latex','fontsize',18);
ylabel('$v_g/c-1$','interpreter','latex','fontsize',18);
axis([0,max(NA_size_theo)+min(NA_size_theo),-0.016,0]);
set(gca,'XTick',(0:0.05:0.35));
set(gca,'xticklabel',{'0','0.05','0.10','0.15','0.20','0.25','0.30','0.35'});
set(gca,'YTick',(-0.016:0.004:0));
set(gca,'yticklabel',{'-1.6%','-1.2%', '-0.8%', '-0.4%', '0'});
grid on; set(gca,'GridLineStyle','--','GridAlpha',0.2);
set(gca,'FontName','Times New Roman');
hold off

text(0.004,0.0195,'\bf(a)','Fontsize',22,'FontName','Times New Roman','color','k');
text(0.004,-0.0015,'\bf(b)','Fontsize',22,'FontName','Times New Roman','color','k');
