function [Speckle_k,normal_kr2_prob,average_kr2,ideal_kr2_prob,average_kr2_ideal] = Interfering_FFT(rand_tilt_x,rand_tilt_y,zoomin_rate,tilt_max,rand_phase)
% This program function is used to interfering tilt Gaussian planewave
% Input: random distribution of tilt angle (along x/y); display window zoom-in rate
% Output description as follow:
% Speckle_k: k spectrum of speckle along a/y
% K_prob: k spectrum of speckle along a/y (zoom-in)
% normal_kr2_prob: normalmized probability distribution of kr^2
% Write by Zhenyu Wan on 2022/05/13
%% Test
% zoomin_rate = 1;         % zoom in the calculated k spectrum
% tilt_max = 1*pi/180;     % maximum (or variance) tilt angle for wave front with x/y
% rand_phase = unifrnd(0,2*pi,interfering_num,1);       % random phase of each components
% rand_Gaussian = abs(randn(interfering_num,1));
% rand_tilt_r = tilt_max*sqrt(rand_Gaussian/max(rand_Gaussian))*max(rand_Gaussian);
% rand_tilt_a = 2*pi*rand(interfering_num,1);
% rand_tilt_x = rand_tilt_r.*cos(rand_tilt_a);           % random tilt angle x
% rand_tilt_y = rand_tilt_r.*sin(rand_tilt_a);           % random tilt angle y
%% Basic Setting
lambda = 1550e-9;        % wavelength (unit: m)
waist0 = 2e-3;           % waist size of Gaussian components (unit: m)
Propagation_z = 0;       % Propagation diatance1 for Gaussian (unit: m)
pixel_size = 2.0e-6;     % pixel spacing (unit: m)
pixel_num = 1000;        % half of screen pixel number of x/y (screen_size = pixel_size *pixel_num)
interfering_num = 1000;  % number of superposed Gaussian components
k0 = 2*pi/lambda;
%% Interfering every tilt Gaussian component
Speckle_E = zeros(pixel_num*2+1,pixel_num*2+1);    % get a speckle pattern matrix for Gaussian
E0 = 1;                                            % the constant term of amplitude of this component
for n = 1:1:interfering_num
    Gaussian_E = Tilt_Gaussian(E0,pixel_num,pixel_size,rand_tilt_x(n),rand_tilt_y(n),lambda,waist0,Propagation_z,rand_phase(n));
    Speckle_E = Gaussian_E+Speckle_E;
end
%% Fourier transform of speckle pattern for calculating k spectrum
Speckle_k = fftshift(fft2(Speckle_E));                          % k spectrum (x-y plane) @ Uniform
kx_axis = (-pixel_num:pixel_num)/(2*pixel_size*pixel_num)*2*pi; % x axis of k spectrum
ky_axis = kx_axis;                                              % y axis of k spectrum

zoomin = round(pixel_num*(1-zoomin_rate));       % the cut-down shown figure's pixel
Speckle_k_zoomin = abs(Speckle_k(zoomin+1:pixel_num*2+1-zoomin,zoomin+1:pixel_num*2+1-zoomin));  % cut-down k-spectrum
% Background reduction
K_prob_sort = sort(Speckle_k_zoomin(:),'descend');
Speckle_k_zoomin(Speckle_k_zoomin(:)<K_prob_sort(interfering_num*50)) = Speckle_k_zoomin(Speckle_k_zoomin(:)<K_prob_sort(interfering_num*50))/4;

kx_axis_zoomin = kx_axis(zoomin+1:pixel_num*2+1-zoomin);            % cut-down kx axis
ky_axis_zoomin = ky_axis(zoomin+1:pixel_num*2+1-zoomin);            % cut-down ky axis
%% k-spectrum data for kr^2 curves
[KX_axis_zoomin,KY_axis_zoomin] = meshgrid(kx_axis_zoomin,ky_axis_zoomin); % Cartesian coordinate of k spectrum (zoom in)
KR2_axis_zoomin = KX_axis_zoomin.^2+KY_axis_zoomin.^2;                     % kr^2 of each k spectrum point (zoom in)
K_prob_zoomin = Speckle_k_zoomin/max(max(Speckle_k_zoomin));   % normalized probability of each k spectrum point at z2 (zoom in)
pixel_num_zoomin = round(pixel_num*zoomin_rate);
kr2_axis = linspace(0,max(max(KX_axis_zoomin))^2,pixel_num_zoomin);   % divide the kr^2 axis evenly
kr2_prob = zeros(1,pixel_num_zoomin);                        % preset the array of probability of kr^2

for p = 1:1:pixel_num_zoomin-1           % each ring area along kr & kr^2 axis
    kr2_prob(1,p) = sum(sum(K_prob_zoomin(KR2_axis_zoomin(:)>=kr2_axis(p) & KR2_axis_zoomin(:)<kr2_axis(p+1))));% sum of k^2 spectrum points within each ring area
end

% filtering the background noise in calculated k-spectrum
sigma = k0*sin(tilt_max);
pixel_num_filter = round(pixel_num_zoomin/max(kr2_axis)*(sigma*5)^2);
kr2_prob(pixel_num_filter:pixel_num_zoomin) = kr2_prob(pixel_num_filter:pixel_num_zoomin)/50;

% kr^2 curve of speckle pattern
normal_kr2_prob = kr2_prob/sum(kr2_prob(:));        % global normalized probability of kr^2
average_kr2 = kr2_axis(1:pixel_num_zoomin)*normal_kr2_prob(1:pixel_num_zoomin)';
% theoretical kr^2 curve for Gaussian case
sigma = k0*sin(tilt_max);
ideal_kr2_prob = sqrt(2*pi*kr2_axis/(sigma^2)).*exp(-kr2_axis/2/(sigma^2));
ideal_kr2_prob = ideal_kr2_prob/sum(ideal_kr2_prob(:));
average_kr2_ideal = kr2_axis(1:pixel_num_zoomin)*ideal_kr2_prob(1:pixel_num_zoomin)';

end