function [ Eout ] = Tilt_Gaussian(E0,pixel_num,pixel_size,tilt_x,tilt_y,lambda,waist0,z,rand_phase)
% This function is used to generate tilt Gaussian planewave
% Detailed explanation goes here
% E0: the constant term of amplitude
% pixel_num: screen pixel number of x/y
% pixel_size is the pixel spacing (unit: m)
% tilt_x,tilt_y: tilt angle for wave front with x/y
% lambda: Wavelength (unit: m)
% waist0: Waist size @ z=0
% z: Propagation distance
% Write by Zhenyu Wan on 2022/04/30
%% test
% E0 = 1;
% pixel_num = 2000;
% pixel_size = 2.0e-6;
% tilt_x = 1*pi/180;
% tilt_y = 1*pi/180;
% lambda = 1550e-9;
% waist0 = 2e-3;
% z = 0;
% rand_phase = 0*pi;
%% Main
LR = pi*waist0^2/lambda;         % Reyleigh length
wz = waist0*sqrt(1+(z/LR)^2);    % waist size @ z
Rz = z+LR^2/z;                   % radius curvature @z

k0 = 2*pi/lambda;                % total wave vector
kx = k0*sin(tilt_x);             % wave vector x
ky = k0*sin(tilt_y);             % wave vector y
kz = sqrt(k0^2-kx^2-ky^2);       % wave vector z

x = -pixel_num*pixel_size:pixel_size:pixel_num*pixel_size;
[X,Y] = meshgrid(x);           % Cartesian coordinate
Rho = sqrt(X.^2+Y.^2);         % radius at the local transverse plane

E_phase = -atan(z/LR) +k0*Rho.^2/2/Rz +z*kz +X.*kx +Y.*ky+rand_phase;   %  transverse phase matrix (considering Gouy phase, curvature phase, longitudinal and transverse phase)
E_amplitude = E0 * waist0/wz * exp(-Rho.^2/wz.^2);           % Gaussian amplitude profile without considering the relationship of scattered power with scattered angle
% E_amplitude = E0;                                          % planewave amplitude profile

Eout=E_amplitude.*exp(1i*E_phase);   % calculated field of tilt Gaussian beam
%% test
% imagesc(abs(Eout));
% figure
% imagesc(mod(angle(Eout),2*pi));
end